@@ -47,12 +47,12 @@ public:
 
     void zwp_keyboard_shortcuts_inhibitor_v1_active() override
     {
-        emit inhibitorActive();
+        Q_EMIT inhibitorActive();
     }
 
     void zwp_keyboard_shortcuts_inhibitor_v1_inactive() override
     {
-        emit inhibitorInactive();
+        Q_EMIT inhibitorInactive();
     }
 
 Q_SIGNALS:
@@ -100,7 +100,6 @@ void TestKeyboardShortcutsInhibitorInterface::initTestCase()
     QVERIFY(m_display.isRunning());
 
     m_seat = new SeatInterface(&m_display, this);
-    m_seat->create();
     m_serverCompositor = new CompositorInterface(&m_display, this);
     m_manager = new KeyboardShortcutsInhibitManagerV1Interface(&m_display, this);
 
