@@ -3,8 +3,7 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef WAYLAND_SERVER_GLOBAL_P_H
-#define WAYLAND_SERVER_GLOBAL_P_H
+#pragma once
 
 #include "global.h"
 
@@ -45,5 +44,3 @@ protected:
 };
 
 }
-
-#endif
