@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef WAYLAND_SERVER_KEYBOARD_SHORTCUTS_INHIBIT_V1_INTERFACE_H
-#define WAYLAND_SERVER_KEYBOARD_SHORTCUTS_INHIBIT_V1_INTERFACE_H
+#pragma once
 
 #include <KWaylandServer/kwaylandserver_export.h>
 #include <QObject>
@@ -47,8 +46,6 @@ private:
  * The KeyboardShortcutsInhibitManagerV1Interface allows clients to inhibit global shortcuts.
  *
  * KeyboardShortcutsInhibitManagerV1Interface correponds to the wayland interface zwp_keyboard_shortcuts_inhibit_manager_v1.
- *
- * @since 5.20
  */
 class KWAYLANDSERVER_EXPORT KeyboardShortcutsInhibitManagerV1Interface : public QObject
 {
@@ -76,5 +73,3 @@ private:
 };
 
 }
-
-#endif
