@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef KWAYLAND_KEYSTATE_INTERFACE_H
-#define KWAYLAND_KEYSTATE_INTERFACE_H
+#pragma once
 
 #include <KWaylandServer/kwaylandserver_export.h>
 #include <QObject>
@@ -18,9 +17,7 @@ class KeyStateInterfacePrivate;
 
 /**
  * @brief Exposes key states to wayland clients
- *
- * @since 5.58
- **/
+ */
 class KWAYLANDSERVER_EXPORT KeyStateInterface : public QObject
 {
     Q_OBJECT
@@ -49,5 +46,3 @@ private:
 };
 
 }
-
-#endif
