@@ -1,20 +1,17 @@
 /*
     SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
+    SPDX-FileCopyrightText: 2021 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef WAYLAND_SERVER_OUTPUT_INTERFACE_H
-#define WAYLAND_SERVER_OUTPUT_INTERFACE_H
+#pragma once
+
+#include <KWaylandServer/kwaylandserver_export.h>
 
 #include <QObject>
 #include <QPoint>
 #include <QSize>
 
-#include <KWaylandServer/kwaylandserver_export.h>
-#include "global.h"
-
-struct wl_global;
-struct wl_client;
 struct wl_resource;
 
 namespace KWaylandServer
@@ -22,12 +19,13 @@ namespace KWaylandServer
 
 class ClientConnection;
 class Display;
+class OutputInterfacePrivate;
 
 /**
- * @brief Global for the wl_output interface.
- *
- **/
-class KWAYLANDSERVER_EXPORT OutputInterface : public Global
+ * The OutputInterface class represents a screen. This class corresponds to the Wayland
+ * interface @c wl_output.
+ */
+class KWAYLANDSERVER_EXPORT OutputInterface : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(QSize physicalSize READ physicalSize WRITE setPhysicalSize NOTIFY physicalSizeChanged)
@@ -44,7 +42,7 @@ public:
         HorizontalRGB,
         HorizontalBGR,
         VerticalRGB,
-        VerticalBGR
+        VerticalBGR,
     };
     enum class Transform {
         Normal,
@@ -54,25 +52,23 @@ public:
         Flipped,
         Flipped90,
         Flipped180,
-        Flipped270
+        Flipped270,
     };
-    enum class ModeFlag {
-        Current = 1,
-        Preferred = 2
-    };
-    Q_DECLARE_FLAGS(ModeFlags, ModeFlag)
     struct Mode {
         QSize size = QSize();
         int refreshRate = 60000;
-        ModeFlags flags;
     };
     enum class DpmsMode {
         On,
         Standby,
         Suspend,
-        Off
+        Off,
     };
-    virtual ~OutputInterface();
+
+    explicit OutputInterface(Display *display, QObject *parent = nullptr);
+    ~OutputInterface() override;
+
+    void remove();
 
     QSize physicalSize() const;
     QPoint globalPosition() const;
@@ -83,7 +79,7 @@ public:
     int scale() const;
     SubPixel subPixel() const;
     Transform transform() const;
-    QList<Mode> modes() const;
+    Mode mode() const;
     bool isDpmsSupported() const;
     DpmsMode dpmsMode() const;
 
@@ -94,34 +90,35 @@ public:
     void setScale(int scale);
     void setSubPixel(SubPixel subPixel);
     void setTransform(Transform transform);
-    void addMode(const QSize &size, ModeFlags flags = ModeFlags(), int refreshRate = 60000);
-    void setCurrentMode(const QSize &size, int refreshRate = 60000);
+    void setMode(const Mode &mode);
+    void setMode(const QSize &size, int refreshRate = 60000);
 
     /**
      * Sets whether Dpms is supported for this output.
      * Default is @c false.
-     * @since 5.5
-     **/
+     */
     void setDpmsSupported(bool supported);
     /**
      * Sets the currently used dpms mode.
      * Default is @c DpmsMode::On.
-     * @since 5.5
-     **/
+     */
     void setDpmsMode(DpmsMode mode);
 
     /**
      * @returns all wl_resources bound for the @p client
-     * @since 5.27
-     **/
+     */
     QVector<wl_resource *> clientResources(ClientConnection *client) const;
 
     /**
      * Returns @c true if the output is on; otherwise returns false.
-     * @since 5.20
      */
     bool isEnabled() const;
 
+    /**
+     * Submit changes to all clients.
+     */
+    void done();
+
     static OutputInterface *get(wl_resource *native);
 
 Q_SIGNALS:
@@ -134,30 +131,29 @@ Q_SIGNALS:
     void scaleChanged(int);
     void subPixelChanged(SubPixel);
     void transformChanged(Transform);
-    void modesChanged();
-    void currentModeChanged();
+    void modeChanged();
     void dpmsModeChanged();
     void dpmsSupportedChanged();
+    void removed();
 
     /**
      * Change of dpms @p mode is requested.
      * A server is free to ignore this request.
-     * @since 5.5
-     **/
+     */
     void dpmsModeRequested(KWaylandServer::OutputInterface::DpmsMode mode);
 
+    /**
+     * Emitted when a client binds to a given output
+     * @internal
+     */
+    void bound(ClientConnection *client,  wl_resource *boundResource);
+
 private:
-    friend class Display;
-    explicit OutputInterface(Display *display, QObject *parent = nullptr);
-    class Private;
-    Private *d_func() const;
+    QScopedPointer<OutputInterfacePrivate> d;
 };
 
-}
+} // namespace KWaylandServer
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(KWaylandServer::OutputInterface::ModeFlags)
 Q_DECLARE_METATYPE(KWaylandServer::OutputInterface::SubPixel)
 Q_DECLARE_METATYPE(KWaylandServer::OutputInterface::Transform)
 Q_DECLARE_METATYPE(KWaylandServer::OutputInterface::DpmsMode)
-
-#endif
