@@ -3,38 +3,37 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef KWAYLAND_SERVER_OUTPUTMANAGEMENT_INTERFACE_H
-#define KWAYLAND_SERVER_OUTPUTMANAGEMENT_INTERFACE_H
+#pragma once
 
-#include "global.h"
+#include <QObject>
 
 #include <KWaylandServer/kwaylandserver_export.h>
 
 namespace KWaylandServer
 {
 
+class OutputManagementInterfacePrivate;
 class OutputConfigurationInterface;
 /**
  * @class OutputManagementInterface
  *
  * This class is used to change the configuration of the Wayland server's outputs.
  * The client requests an OutputConfiguration, changes its OutputDevices and then
- * calls OutputConfiguration::apply, which makes this class emit a signal, carrying
+ * calls OutputConfiguration::apply, which makes this class Q_EMIT a signal, carrying
  * the new configuration.
  * The server is then expected to make the requested changes by applying the settings
  * of the OutputDevices to the Outputs.
  *
  * @see OutputConfiguration
  * @see OutputConfigurationInterface
- * @since 5.5
  */
-class KWAYLANDSERVER_EXPORT OutputManagementInterface : public Global
+class KWAYLANDSERVER_EXPORT OutputManagementInterface : public QObject
 {
     Q_OBJECT
 
 public:
     explicit OutputManagementInterface(Display *display, QObject *parent = nullptr);
-    virtual ~OutputManagementInterface();
+    ~OutputManagementInterface() override;
 
 Q_SIGNALS:
     /**
@@ -53,9 +52,7 @@ Q_SIGNALS:
     void configurationChangeRequested(KWaylandServer::OutputConfigurationInterface *configurationInterface);
 
 private:
-    class Private;
+    QScopedPointer<OutputManagementInterfacePrivate> d;
 };
 
 }
-
-#endif
